==> dokuwiki_0.0.20061106.orig.tar.gz: dokuwiki-2006-11-06/inc/lang/it/lang.php <==
<?php
/**
 * Italian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Giorgio Vecchiocattivi <giorgio@vecchio.it>
 * @author     Roberto Bolli <http://www.rbnet.it/>
 * @author     Silvia Sargentoni <polinnia@tin.it>
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';

$lang['btn_edit']   = 'Modifica questa pagina';
$lang['btn_source'] = 'Mostra sorgente';
$lang['btn_show']   = 'Mostra pagina';
$lang['btn_create'] = 'Crea questa pagina';
$lang['btn_search'] = 'Cerca';
$lang['btn_save']   = 'Salva';
$lang['btn_preview']= 'Anteprima';
$lang['btn_top']    = 'Torna su';
$lang['btn_newer']  = '<< più recenti';
$lang['btn_older']  = 'meno recenti >>';
$lang['btn_revs']   = 'Revisioni precedenti';
$lang['btn_recent'] = 'Ultime modifiche';
$lang['btn_upload'] = 'Invia file';
$lang['btn_cancel'] = 'Annulla';
$lang['btn_index']  = 'Indice';
$lang['btn_secedit']= 'Modifica';
$lang['btn_login']  = 'Entra';
$lang['btn_logout'] = 'Esci';
$lang['btn_admin']  = 'Amministrazione';
$lang['btn_update'] = 'Aggiorna';
$lang['btn_delete'] = 'Cancella';
$lang['btn_back']   = 'Indietro';
$lang['btn_backlink']    = "Backlinks";
$lang['btn_backtomedia'] = 'Torna alla selezione file';
$lang['btn_subscribe']   = 'Sottoscrivi modifiche';
$lang['btn_unsubscribe'] = 'Cancella sottoscrizione';
$lang['btn_profile']     = 'Aggiorna profilo';
$lang['btn_reset']       = 'Azzera';
$lang['btn_resendpwd']   = 'Invia nuova password';
$lang['btn_draft']    = 'Modifica bozza';
$lang['btn_recover']  = 'Ripristina bozza';
$lang['btn_draftdel'] = 'Cancella bozza';

$lang['loggedinas'] = 'Collegato come';
$lang['user']       = 'Nome utente';
$lang['pass']       = 'Password';
$lang['newpass']    = 'Nuova password';
$lang['oldpass']    = 'Conferma password corrente';
$lang['passchk']    = 'Ripeti password';
$lang['remember']   = 'Ricorda automaticamente';
$lang['fullname']   = 'Nome completo';
$lang['email']      = 'E-Mail';
$lang['register']   = 'Registrazione';
$lang['profile']    = 'Profilo utente';
$lang['badlogin']   = 'Il nome utente o la password non sono validi.';
$lang['minoredit']  = 'Modifiche minori';
$lang['draftdate']  = 'Bozza salvata in automatico il'; // full dformat date will be added

$lang['regmissing'] = 'Devi riempire tutti i campi.';
$lang['reguexists'] = 'Il nome utente inserito esiste già .';
$lang['regsuccess'] = 'L\'utente è stato creato. La password è stata spedita via e-mail.';
$lang['regsuccess2']= 'L\'utente è stato creato.';
$lang['regmailfail']= 'Sembra che ci sia stato un errore nell\'invio della e-mail. Per favore contatta il tuo amministratore!';
$lang['regbadmail'] = 'L\'indirizzo e-mail fornito sembra essere non valido - se pensi che ci sia un errore contatta il tuo amministratore';
$lang['regbadpass'] = 'Le due password inserite non coincidono, prova di nuovo.';
$lang['regpwmail']  = 'La tua password DokuWiki';
$lang['reghere']    = 'Non hai ancora un accesso? Registrati qui.';

$lang['profna']       = 'Questo wiki non supporta modifiche al profilo';
$lang['profnochange'] = 'Nessuna modifica, niente da aggiornare.';
$lang['profnoempty']  = 'Nome o indirizzo email vuoti non sono consentiti.';
$lang['profchanged']  = 'Aggiornamento del profilo utente riuscito.';

$lang['pwdforget'] = 'Hai dimenticato la password? Richiedine una nuova';
$lang['resendna']  = 'Questo wiki non supporta l\'invio di nuove password.';
$lang['resendpwd'] = 'Invia nuova password per';
$lang['resendpwdmissing'] = 'Devi riempire tutti i campi.';
$lang['resendpwdnouser']  = 'Impossibile trovare questo utente nel database.';
$lang['resendpwdbadauth'] = 'Spiacente, questo codice di autorizzazione non è valido. Assicurati di aver usato il link completo di conferma.';
$lang['resendpwdconfirm'] = 'Un link di conferma è stato spedito via email.';
$lang['resendpwdsuccess'] = 'La nuova password è stata spedita via email.';

$lang['txt_upload']   = 'Seleziona un file da caricare';
$lang['txt_filename'] = 'Inserisci un "wikiname" (opzionale)';
$lang['txt_overwrt']  = 'Sovrascrivi file esistente';
$lang['lockedby']     = 'Attualmente bloccato da';
$lang['lockexpire']   = 'Il blocco scade alle';
$lang['willexpire']   = 'Il tuo blocco su questa pagina scadrà tra circa un minuto.\nPer evitare incongruenze usa il pulsante di anteprima per prolungare il periodo di blocco.';

$lang['notsavedyet'] = 'Le modifiche non salvate andranno perse.\nContinuare?';
$lang['rssfailed']   = 'Si è verificato un errore cercando questo feed: ';
$lang['nothingfound']= 'Nessun risultato trovato.';

$lang['mediaselect'] = 'Selezione dei file';
$lang['fileupload']  = 'File caricato';
$lang['uploadsucc']  = 'Invio riuscito';
$lang['uploadfail']  = 'Invio fallito. Contatta l\'amministratore.';
$lang['uploadwrong'] = 'Invio rifiutato. Questa estensione di file non è ammessa';
$lang['uploadexist'] = 'Il file esiste già . Invio annullato.';
$lang['deletesucc']  = 'Il file "%s" è stato cancellato.';
$lang['deletefail']  = '"%s" non può essere cancellato - verifica i permessi.';
$lang['mediainuse']  = 'Il file "%s" non è stato cancellato - è ancora in uso.';
$lang['namespaces']  = 'Categorie';
$lang['mediafiles']  = 'File disponibili in';

$lang['js']['keepopen']    = 'Tieni la finestra aperta durante la selezione';
$lang['js']['hidedetails'] = 'Nascondi Dettagli';
$lang['mediausage']  = 'Usa la seguente sintassi per riferirti a questo file:';
$lang['mediaview']   = 'Mostra file originale';
$lang['mediaroot']   = 'directory principale';
$lang['mediaupload'] = 'Carica un file nella categoria corrente. Per creare sottocategorie, falle precedere al nome del file nella casella "Carica come", separandole da due punti (:).';
$lang['mediaextchange'] = 'Estensione del file modificata da .%s a .%s!';

$lang['reference']   = 'Riferimenti a';
$lang['ref_inuse']   = 'Il file non può essere cancellato in quanto è ancora utilizzato dalle seguenti pagine:';
$lang['ref_hidden']  = 'Sono presenti alcuni riferimenti a pagine per le quali non hai i permessi di lettura';

$lang['hits']       = 'Occorrenze trovate';
$lang['quickhits']  = 'Pagine trovate';
$lang['toc']        = 'Indice';
$lang['current']    = 'versione corrente';
$lang['yours']      = 'la tua versione';
$lang['diff']       = 'differenze con la versione attuale';
$lang['line']       = 'Linea';
$lang['breadcrumb'] = 'Traccia';
$lang['youarehere'] = 'Ti trovi qui';
$lang['lastmod']    = 'Ultima modifica';
$lang['by']         = 'da';
$lang['deleted']    = 'cancellata';
$lang['created']    = 'creata';
$lang['restored']   = 'versione precedente ripristinata';
$lang['summary']    = 'Oggetto della modifica';

$lang['mail_newpage'] = 'pagina aggiunta:';
$lang['mail_changed'] = 'pagina modificata:';
$lang['mail_new_user'] = 'Nuovo utente:';

$lang['nosmblinks'] = 'I collegamenti con le risorse condivise di Windows funzionano solo con Microsoft Internet Explorer.\nPuoi fare un copia/incolla di questo collegamento.';

$lang['qb_alert']   = 'Puoi inserire il testo che vuoi formattare.\nSarÃ  aggiunto alla fine del documento.';
$lang['qb_bold']    = 'Grassetto';
$lang['qb_italic']  = 'Corsivo';
$lang['qb_underl']  = 'Sottolineato';
$lang['qb_code']    = 'Codice';
$lang['qb_strike']  = 'Barrato';
$lang['qb_h1']      = 'Intestazione di livello 1';
$lang['qb_h2']      = 'Intestazione di livello 2';
$lang['qb_h3']      = 'Intestazione di livello 3';
$lang['qb_h4']      = 'Intestazione di livello 4';
$lang['qb_h5']      = 'Intestazione di livello 5';
$lang['qb_link']    = 'Collegamento interno';
$lang['qb_extlink'] = 'Collegamento esterno';
$lang['qb_hr']      = 'Riga orizzontale';
$lang['qb_ol']      = 'Elenco numerato';
$lang['qb_ul']      = 'Elenco puntato';
$lang['qb_media']   = 'Inserisci immagini o altri file';
$lang['qb_sig']     = 'Inserisci la firma';
$lang['qb_smileys'] = 'Smiley';
$lang['qb_chars']   = 'Caratteri speciali';

$lang['del_confirm']= 'Cancellare questa voce?';
$lang['admin_register']= 'Aggiungi un nuovo utente';

$lang['spell_start'] = 'Controllo ortografico';
$lang['spell_stop']  = 'Interrompi controllo';
$lang['spell_wait']  = 'Attendere...';
$lang['spell_noerr'] = 'Nessun errore trovato';
$lang['spell_nosug'] = 'Nessun suggerimento';
$lang['spell_change']= 'Cambia';

$lang['metaedit']    = 'Modifica metadati';
$lang['metasaveerr'] = 'Scrittura metadati fallita';
$lang['metasaveok']  = 'Metadati salvati';
$lang['img_backto']  = 'Torna a';
$lang['img_title']   = 'Titolo';
$lang['img_caption'] = 'Descrizione';
$lang['img_date']    = 'Data';
$lang['img_fname']   = 'Nome File';
$lang['img_fsize']   = 'Dimensione';
$lang['img_artist']  = 'Autore';
$lang['img_copyr']   = 'Copyright';
$lang['img_format']  = 'Formato';
$lang['img_camera']  = 'Camera';
$lang['img_keywords']= 'Parole chiave';

$lang['subscribe_success']  = '%s è stato aggiunto alla lista di sottoscrizione per la pagina %s';
$lang['subscribe_error']    = 'Si è verificato un errore durante l\'aggiunta di %s alla lista di sottoscrizione per la pagina %s';
$lang['subscribe_noaddress']= 'Non c\'è alcun indirizzo associato con il tuo profilo, non puoi sottoscriverti ad alcuna lista';
$lang['unsubscribe_success']= '%s è stato rimosso dalla lista di sottoscrizione per la pagina %s';
$lang['unsubscribe_error']  = 'Si è verificato un errore durante la rimozione di %s dalla lista di sottoscrizione per la pagina %s';

/* auth.class language support */
$lang['authmodfailed']   = 'La configurazione dell\'autenticazione non è corretta. Per favore informa l\'amministratore di questo Wiki.';
$lang['authtempfail']    = 'L\'autenticazione è temporaneamente non disponibile. Se questa situazione persiste, per favore informa l\'amministratore di questo Wiki.';

/* installer strings */
$lang['i_chooselang'] = 'Scegli la lingua';
$lang['i_installer']  = 'Installazione DokuWiki';
$lang['i_wikiname']   = 'Nome Wiki';
$lang['i_enableacl']  = 'Abilita ACL (consigliato)';
$lang['i_superuser']  = 'Amministratore';
$lang['i_problems']   = 'Si sono verificati problemi durante l\'installazione, indicati di seguito. Non è possibile continuare finché non saranno risolti.';
$lang['i_modified']   = 'Per motivi di sicurezza questa procedura funziona solamente con un\'installazione Dokuwiki nuova e non modificata.
                         Dovresti ri-estrarre i file dal pacchetto scaricato oppure consultare tutte le
                         <a href="http://wiki.splitbrain.org/wiki:install">istruzioni per l\'installazione di Dokuwiki</a>';
$lang['i_funcna']     = 'La funzione PHP <code>%s</code> non è disponibile. Forse il tuo provider l\'ha disabilitata per qualche motivo?';
$lang['i_permfail']   = 'DokuWiki non può scrivere <code>%s</code>. E\' necessario correggere i permessi per questa directory!';
$lang['i_confexists'] = '<code>%s</code> esiste già';
$lang['i_writeerr']   = 'Impossibile creare <code>%s</code>. E\' necessario verificare i permessi della directory/file e creare il file manualmente.';
$lang['i_badhash']    = 'dokuwiki.php (hash=<code>%s</code>) non riconosciuto o modificato';
$lang['i_badval']     = '<code>%s</code> - valore vuoto o non valido';
$lang['i_success']    = 'La configurazione è stata completata correttamente. E\' ora possibile cancellare il file install.php. Continuare con
                        <a href="doku.php">il nuovo DokuWiki</a>.';
$lang['i_failure']    = 'Si sono verificati errori durante la scrittura dei file di configurazione. Potrebbe essere necessario correggerli manualmente prima
                         di poter utilizzare <a href="doku.php">il nuovo DokuWiki</a>.';
$lang['i_policy']     = 'Policy di accesso iniziali';
$lang['i_pol0']       = 'Wiki Aperto (lettura, scrittura, caricamento file per tutti)';
$lang['i_pol1']       = 'Wiki Pubblico (lettura per tutti, scrittura e caricamento file per gli utenti registrati)';
$lang['i_pol2']       = 'Wiki Chiuso (lettura, scrittura, caricamento file solamente per gli utenti registrati)';


//Setup VIM: ex: et ts=2 enc=utf-8 :

==> dokuwiki_0.0.20070626b.orig.tar.gz: dokuwiki-2007-06-26b/inc/lang/it/lang.php <==
<?php
/**
 * Italian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Giorgio Vecchiocattivi <giorgio@vecchio.it>
 * @author     Roberto Bolli <http://www.rbnet.it/>
 * @author     Silvia Sargentoni <polinnia@tin.it>
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';
$lang['doublequoteopening']  = '“';//&ldquo;
$lang['doublequoteclosing']  = '”';//&rdquo;
$lang['singlequoteopening']  = '‘';//&lsquo;
$lang['singlequoteclosing']  = '’';//&rsquo;

$lang['btn_edit']   = 'Modifica questa pagina';
$lang['btn_source'] = 'Mostra sorgente';
$lang['btn_show']   = 'Mostra pagina';
$lang['btn_create'] = 'Crea questa pagina';
$lang['btn_search'] = 'Cerca';
$lang['btn_save']   = 'Salva';
$lang['btn_preview']= 'Anteprima';
$lang['btn_top']    = 'Torna su';
$lang['btn_newer']  = '<< più recenti';
$lang['btn_older']  = 'meno recenti >>';
$lang['btn_revs']   = 'Revisioni precedenti';
$lang['btn_recent'] = 'Ultime modifiche';
$lang['btn_upload'] = 'Invia file';
$lang['btn_cancel'] = 'Annulla';
$lang['btn_index']  = 'Indice';
$lang['btn_secedit']= 'Modifica';
$lang['btn_login']  = 'Entra';
$lang['btn_logout'] = 'Esci';
$lang['btn_admin']  = 'Amministrazione';
$lang['btn_update'] = 'Aggiorna';
$lang['btn_delete'] = 'Cancella';
$lang['btn_back']   = 'Indietro';
$lang['btn_backlink']    = "Backlinks";
$lang['btn_backtomedia'] = 'Torna alla selezione file';
$lang['btn_subscribe']   = 'Sottoscrivi modifiche';
$lang['btn_unsubscribe'] = 'Cancella sottoscrizione';
$lang['btn_profile']     = 'Aggiorna profilo';
$lang['btn_reset']       = 'Azzera';
$lang['btn_resendpwd']   = 'Invia nuova password';
$lang['btn_draft']    = 'Modifica bozza';
$lang['btn_recover']  = 'Ripristina bozza';
$lang['btn_draftdel'] = 'Cancella bozza';

$lang['loggedinas'] = 'Collegato come';
$lang['user']       = 'Nome utente';
$lang['pass']       = 'Password';
$lang['newpass']    = 'Nuova password';
$lang['oldpass']    = 'Conferma password corrente';
$lang['passchk']    = 'Ripeti password';
$lang['remember']   = 'Ricorda automaticamente';
$lang['fullname']   = 'Nome completo';
$lang['email']      = 'E-Mail';
$lang['register']   = 'Registrazione';
$lang['profile']    = 'Profilo utente';
$lang['badlogin']   = 'Il nome utente o la password non sono validi.';
$lang['minoredit']  = 'Modifiche minori';
$lang['draftdate']  = 'Bozza salvata in automatico il'; // full dformat date will be added

$lang['regmissing'] = 'Devi riempire tutti i campi.';
$lang['reguexists'] = 'Il nome utente inserito esiste già .';
$lang['regsuccess'] = 'L\'utente è stato creato. La password è stata spedita via e-mail.';
$lang['regsuccess2']= 'L\'utente è stato creato.';
$lang['regmailfail']= 'Sembra che ci sia stato un errore nell\'invio della e-mail. Per favore contatta il tuo amministratore!';
$lang['regbadmail'] = 'L\'indirizzo e-mail fornito sembra essere non valido - se pensi che ci sia un errore contatta il tuo amministratore';
$lang['regbadpass'] = 'Le due password inserite non coincidono, prova di nuovo.';
$lang['regpwmail']  = 'La tua password DokuWiki';
$lang['reghere']    = 'Non hai ancora un accesso? Registrati qui.';

$lang['profna']       = 'Questo wiki non supporta modifiche al profilo';
$lang['profnochange'] = 'Nessuna modifica, niente da aggiornare.';
$lang['profnoempty']  = 'Nome o indirizzo email vuoti non sono consentiti.';
$lang['profchanged']  = 'Aggiornamento del profilo utente riuscito.';

$lang['pwdforget'] = 'Hai dimenticato la password? Richiedine una nuova';
$lang['resendna']  = 'Questo wiki non supporta l\'invio di nuove password.';
$lang['resendpwd'] = 'Invia nuova password per';
$lang['resendpwdmissing'] = 'Devi riempire tutti i campi.';
$lang['resendpwdnouser']  = 'Impossibile trovare questo utente nel database.';
$lang['resendpwdbadauth'] = 'Spiacente, questo codice di autorizzazione non è valido. Assicurati di aver usato il link completo di conferma.';
$lang['resendpwdconfirm'] = 'Un link di conferma è stato spedito via email.';
$lang['resendpwdsuccess'] = 'La nuova password è stata spedita via email.';

$lang['txt_upload']   = 'Seleziona un file da caricare';
$lang['txt_filename'] = 'Inserisci un "wikiname" (opzionale)';
$lang['txt_overwrt']  = 'Sovrascrivi file esistente';
$lang['lockedby']     = 'Attualmente bloccato da';
$lang['lockexpire']   = 'Il blocco scade alle';
$lang['willexpire']   = 'Il tuo blocco su questa pagina scadrà tra circa un minuto.\nPer evitare incongruenze usa il pulsante di anteprima per prolungare il periodo di blocco.';

$lang['notsavedyet'] = 'Le modifiche non salvate andranno perse.\nContinuare?';
$lang['rssfailed']   = 'Si è verificato un errore cercando questo feed: ';
$lang['nothingfound']= 'Nessun risultato trovato.';

$lang['mediaselect'] = 'Selezione dei file';
$lang['fileupload']  = 'File caricato';
$lang['uploadsucc']  = 'Invio riuscito';
$lang['uploadfail']  = 'Invio fallito. Contatta l\'amministratore.';
$lang['uploadwrong'] = 'Invio rifiutato. Questa estensione di file non è ammessa';
$lang['uploadexist'] = 'Il file esiste già . Invio annullato.';
$lang['deletesucc']  = 'Il file "%s" è stato cancellato.';
$lang['deletefail']  = '"%s" non può essere cancellato - verifica i permessi.';
$lang['mediainuse']  = 'Il file "%s" non è stato cancellato - è ancora in uso.';
$lang['namespaces']  = 'Categorie';
$lang['mediafiles']  = 'File disponibili in';

$lang['js']['keepopen']    = 'Tieni la finestra aperta durante la selezione';
$lang['js']['hidedetails'] = 'Nascondi Dettagli';
$lang['mediausage']  = 'Usa la seguente sintassi per riferirti a questo file:';
$lang['mediaview']   = 'Mostra file originale';
$lang['mediaroot']   = 'directory principale';
$lang['mediaupload'] = 'Carica un file nella categoria corrente. Per creare sottocategorie, falle precedere al nome del file nella casella "Carica come", separandole da due punti (:).';
$lang['mediaextchange'] = 'Estensione del file modificata da .%s a .%s!';

$lang['reference']   = 'Riferimenti a';
$lang['ref_inuse']   = 'Il file non può essere cancellato in quanto è ancora utilizzato dalle seguenti pagine:';
$lang['ref_hidden']  = 'Sono presenti alcuni riferimenti a pagine per le quali non hai i permessi di lettura';

$lang['hits']       = 'Occorrenze trovate';
$lang['quickhits']  = 'Pagine trovate';
$lang['toc']        = 'Indice';
$lang['current']    = 'versione corrente';
$lang['yours']      = 'la tua versione';
$lang['diff']       = 'differenze con la versione attuale';
$lang['line']       = 'Linea';
$lang['breadcrumb'] = 'Traccia';
$lang['youarehere'] = 'Ti trovi qui';
$lang['lastmod']    = 'Ultima modifica';
$lang['by']         = 'da';
$lang['deleted']    = 'cancellata';
$lang['created']    = 'creata';
$lang['restored']   = 'versione precedente ripristinata';
$lang['summary']    = 'Oggetto della modifica';

$lang['mail_newpage'] = 'pagina aggiunta:';
$lang['mail_changed'] = 'pagina modificata:';
$lang['mail_new_user'] = 'Nuovo utente:';

$lang['nosmblinks'] = 'I collegamenti con le risorse condivise di Windows funzionano solo con Microsoft Internet Explorer.\nPuoi fare un copia/incolla di questo collegamento.';

$lang['qb_alert']   = 'Puoi inserire il testo che vuoi formattare.\nSarÃ  aggiunto alla fine del documento.';
$lang['qb_bold']    = 'Grassetto';
$lang['qb_italic']  = 'Corsivo';
$lang['qb_underl']  = 'Sottolineato';
$lang['qb_code']    = 'Codice';
$lang['qb_strike']  = 'Barrato';
$lang['qb_h1']      = 'Intestazione di livello 1';
$lang['qb_h2']      = 'Intestazione di livello 2';
$lang['qb_h3']      = 'Intestazione di livello 3';
$lang['qb_h4']      = 'Intestazione di livello 4';
$lang['qb_h5']      = 'Intestazione di livello 5';
$lang['qb_link']    = 'Collegamento interno';
$lang['qb_extlink'] = 'Collegamento esterno';
$lang['qb_hr']      = 'Riga orizzontale';
$lang['qb_ol']      = 'Elenco numerato';
$lang['qb_ul']      = 'Elenco puntato';
$lang['qb_media']   = 'Inserisci immagini o altri file';
$lang['qb_sig']     = 'Inserisci la firma';
$lang['qb_smileys'] = 'Smiley';
$lang['qb_chars']   = 'Caratteri speciali';

$lang['del_confirm']= 'Cancellare questa voce?';
$lang['admin_register']= 'Aggiungi un nuovo utente';

$lang['spell_start'] = 'Controllo ortografico';
$lang['spell_stop']  = 'Interrompi controllo';
$lang['spell_wait']  = 'Attendere...';
$lang['spell_noerr'] = 'Nessun errore trovato';
$lang['spell_nosug'] = 'Nessun suggerimento';
$lang['spell_change']= 'Cambia';

$lang['metaedit']    = 'Modifica metadati';
$lang['metasaveerr'] = 'Scrittura metadati fallita';
$lang['metasaveok']  = 'Metadati salvati';
$lang['img_backto']  = 'Torna a';
$lang['img_title']   = 'Titolo';
$lang['img_caption'] = 'Descrizione';
$lang['img_date']    = 'Data';
$lang['img_fname']   = 'Nome File';
$lang['img_fsize']   = 'Dimensione';
$lang['img_artist']  = 'Autore';
$lang['img_copyr']   = 'Copyright';
$lang['img_format']  = 'Formato';
$lang['img_camera']  = 'Camera';
$lang['img_keywords']= 'Parole chiave';

$lang['subscribe_success']  = '%s è stato aggiunto alla lista di sottoscrizione per la pagina %s';
$lang['subscribe_error']    = 'Si è verificato un errore durante l\'aggiunta di %s alla lista di sottoscrizione per la pagina %s';
$lang['subscribe_noaddress']= 'Non c\'è alcun indirizzo associato con il tuo profilo, non puoi sottoscriverti ad alcuna lista';
$lang['unsubscribe_success']= '%s è stato rimosso dalla lista di sottoscrizione per la pagina %s';
$lang['unsubscribe_error']  = 'Si è verificato un errore durante la rimozione di %s dalla lista di sottoscrizione per la pagina %s';

/* auth.class language support */
$lang['authmodfailed']   = 'La configurazione dell\'autenticazione non è corretta. Per favore informa l\'amministratore di questo Wiki.';
$lang['authtempfail']    = 'L\'autenticazione è temporaneamente non disponibile. Se questa situazione persiste, per favore informa l\'amministratore di questo Wiki.';

/* installer strings */
$lang['i_chooselang'] = 'Scegli la lingua';
$lang['i_installer']  = 'Installazione DokuWiki';
$lang['i_wikiname']   = 'Nome Wiki';
$lang['i_enableacl']  = 'Abilita ACL (consigliato)';
$lang['i_superuser']  = 'Amministratore';
$lang['i_problems']   = 'Si sono verificati problemi durante l\'installazione, indicati di seguito. Non è possibile continuare finché non saranno risolti.';
$lang['i_modified']   = 'Per motivi di sicurezza questa procedura funziona solamente con un\'installazione Dokuwiki nuova e non modificata.
                         Dovresti ri-estrarre i file dal pacchetto scaricato oppure consultare tutte le
                         <a href="http://wiki.splitbrain.org/wiki:install">istruzioni per l\'installazione di Dokuwiki</a>';
$lang['i_funcna']     = 'La funzione PHP <code>%s</code> non è disponibile. Forse il tuo provider l\'ha disabilitata per qualche motivo?';
$lang['i_permfail']   = 'DokuWiki non può scrivere <code>%s</code>. E\' necessario correggere i permessi per questa directory!';
$lang['i_confexists'] = '<code>%s</code> esiste già';
$lang['i_writeerr']   = 'Impossibile creare <code>%s</code>. E\' necessario verificare i permessi della directory/file e creare il file manualmente.';
$lang['i_badhash']    = 'dokuwiki.php (hash=<code>%s</code>) non riconosciuto o modificato';
$lang['i_badval']     = '<code>%s</code> - valore vuoto o non valido';
$lang['i_success']    = 'La configurazione è stata completata correttamente. E\' ora possibile cancellare il file install.php. Continuare con
                        <a href="doku.php">il nuovo DokuWiki</a>.';
$lang['i_failure']    = 'Si sono verificati errori durante la scrittura dei file di configurazione. Potrebbe essere necessario correggerli manualmente prima
                         di poter utilizzare <a href="doku.php">il nuovo DokuWiki</a>.';
$lang['i_policy']     = 'Policy di accesso iniziali';
$lang['i_pol0']       = 'Wiki Aperto (lettura, scrittura, caricamento file per tutti)';
$lang['i_pol1']       = 'Wiki Pubblico (lettura per tutti, scrittura e caricamento file per gli utenti registrati)';
$lang['i_pol2']       = 'Wiki Chiuso (lettura, scrittura, caricamento file solamente per gli utenti registrati)';


//Setup VIM: ex: et ts=2 enc=utf-8 :
